@@ -145,7 +145,11 @@ static gboolean   xfwm_settings_active_frame_draw                    (GtkWidget
                                                                       cairo_t              *cr,
                                                                       XfwmSettings         *settings);
 static gboolean   xfwm_settings_signal_blocker                       (GtkWidget            *widget);
+
+/* FIXME! */
+#if 0
 static GdkPixbuf *xfwm_settings_create_icon_from_widget              (GtkWidget            *widget);
+#endif
 
 static void       xfwm_settings_save_button_layout                   (XfwmSettings          *settings,
                                                                       GtkContainer          *container);
@@ -1205,14 +1209,16 @@ xfwm_settings_hidden_frame_drag_data (GtkWidget        *widget,
 static gboolean
 xfwm_settings_title_button_press_event (GtkWidget *widget)
 {
+ /* FIXME! This crashes in cairo... xfce bug 14606 */
+#if 0
   GdkPixbuf *pixbuf;
 
   g_return_val_if_fail (GTK_IS_WIDGET (widget), TRUE);
-
   /* set pixbuf before drag begin cause it can be not displayed */
   pixbuf = xfwm_settings_create_icon_from_widget (widget);
   gtk_drag_source_set_icon_pixbuf (widget, pixbuf);
   g_object_unref (pixbuf);
+#endif
 
   return TRUE;
 }
@@ -1341,7 +1347,8 @@ xfwm_settings_signal_blocker (GtkWidget *widget)
 }
 
 
-
+/* FIXME! This crashes in cairo... xfce bug 14606 */
+#if 0
 static GdkPixbuf *
 xfwm_settings_create_icon_from_widget (GtkWidget *widget)
 {
@@ -1356,7 +1363,7 @@ xfwm_settings_create_icon_from_widget (GtkWidget *widget)
                                      allocation.x, allocation.y,
                                      allocation.width, allocation.height);
 }
-
+#endif
 
 
 static void
@@ -1404,7 +1411,7 @@ xfwm_settings_button_layout_property_changed (XfconfChannel *channel,
                             gtk_container_get_children (GTK_CONTAINER (hidden_box)));
 
   /* Move buttons to the active list */
-  for (str_value = g_value_get_string (value); *str_value != '\0'; ++str_value)
+  for (str_value = g_value_get_string (value); str_value != NULL && *str_value != '\0'; ++str_value)
     for (iter = children; iter != NULL; iter = g_list_next (iter))
       {
         button = GTK_WIDGET (iter->data);
