@@ -95,7 +95,7 @@ xfwmWindowCreate (ScreenInfo * screen_info, Visual *visual, gint depth, Window p
     XSetWindowAttributes attributes;
     unsigned long valuemask;
 
-    TRACE ("entering xfwmWindowCreate");
+    TRACE ("parent (0x%lx)", parent);
 
     g_return_if_fail (screen_info != NULL);
 
@@ -111,7 +111,7 @@ xfwmWindowCreate (ScreenInfo * screen_info, Visual *visual, gint depth, Window p
                                  InputOutput, CopyFromParent,
                                  valuemask, &attributes);
 
-    TRACE ("Created XID 0x%lx", win->window);
+    TRACE ("new XID (0x%lx)", win->window);
 
     win->map = FALSE;
     win->screen_info = screen_info;
@@ -124,12 +124,17 @@ xfwmWindowCreate (ScreenInfo * screen_info, Visual *visual, gint depth, Window p
 #ifdef HAVE_RENDER
     win->pict_format = XRenderFindVisualFormat (myScreenGetXDisplay (screen_info), win->visual);
 #endif
+#ifdef HAVE_XI2
+    xfwm_device_configure_xi2_event_mask (screen_info->display_info->devices,
+                                          screen_info->display_info->dpy,
+                                          win->window, eventmask);
+#endif
 }
 
 void
 xfwmWindowDelete (xfwmWindow * win)
 {
-    TRACE ("entering xfwmWindowDelete");
+    TRACE ("win %p (0x%lx)", win, win->window);
 
     if (win->window != None)
     {
@@ -144,7 +149,7 @@ void
 xfwmWindowShow (xfwmWindow * win, int x, int y, int width, int height,
     gboolean refresh)
 {
-    TRACE ("entering xfwmWindowShow");
+    TRACE ("win %p (0x%lx) at (%i,%i) [%i×%i]", win, win->window, x, y, width, height);
 
     if (!(win->window))
     {
@@ -161,7 +166,7 @@ xfwmWindowShow (xfwmWindow * win, int x, int y, int width, int height,
                     win->window);
         win->map = TRUE;
     }
-    TRACE ("Showing XID 0x%lx", win->window);
+
     if (((x != win->x) || (y != win->y)) && ((width != win->width)
             || (height != win->height)))
     {
@@ -206,7 +211,7 @@ xfwmWindowShow (xfwmWindow * win, int x, int y, int width, int height,
 void
 xfwmWindowHide (xfwmWindow * win)
 {
-    TRACE ("entering xfwmWindowHide");
+    TRACE ("win %p (0x%lx)", win, win->window);
 
     if (win->map)
     {
@@ -266,6 +271,11 @@ xfwmWindowTemp (ScreenInfo *screen_info, Visual *visual,
     win->width = width;
     win->height = height;
     xfwmWindowSetVisual (win, visual, depth);
+#ifdef HAVE_XI2
+    xfwm_device_configure_xi2_event_mask (screen_info->display_info->devices,
+                                          screen_info->display_info->dpy,
+                                          win->window, eventmask);
+#endif
 }
 
 #ifdef HAVE_RENDER
@@ -279,13 +289,13 @@ xfwmWindowCopyComposite (xfwmWindow * win, xfwmPixmap * pix)
 
         if (!pix->pict)
         {
-            TRACE ("xfwmWindowCopyComposite: Pixmap picture does not exist");
+            TRACE ("pixmap picture does not exist");
             return FALSE;
         }
 
         if (!win->pict_format)
         {
-            TRACE ("xfwmWindowCopyComposite: Window picture format is unknown");
+            TRACE ("window picture format is unknown");
             return FALSE;
         }
 
