@@ -155,13 +155,6 @@ enum
     PLACE_CENTER
 };
 
-struct _XfwmColor
-{
-    GdkColor col;
-    GdkGC *gc;
-    gboolean allocated;
-};
-
 struct _Settings
 {
     gchar  *option;
@@ -208,6 +201,7 @@ struct _XfwmParams
     gboolean click_to_focus;
     gboolean cycle_apps_only;
     gboolean cycle_draw_frame;
+    gboolean cycle_raise;
     gboolean cycle_hidden;
     gboolean cycle_minimum;
     gboolean cycle_preview;
@@ -230,7 +224,6 @@ struct _XfwmParams
     gboolean snap_resist;
     gboolean snap_to_border;
     gboolean snap_to_windows;
-    gboolean sync_to_vblank;
     gboolean tile_on_move;
     gboolean title_vertical_offset_active;
     gboolean title_vertical_offset_inactive;
